DocxBorderSide class

Defines a single border side properties.

Constructors

DocxBorderSide({DocxBorder style = DocxBorder.single, DocxColor color = DocxColor.black, int size = 4, int space = 0, String? themeColor, String? themeTint, String? themeShade, String? rawVal})
const
DocxBorderSide.none()
const

Properties

color DocxColor
final
hashCode int
The hash code for this object.
no setterinherited
rawVal String?
Raw XML value for border style if it doesn't match DocxBorder enum.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
Border width in eighths of a point (4 = 0.5pt, 8 = 1pt).
final
space int
final
style DocxBorder
final
themeColor String?
Theme color reference (e.g. 'accent1').
final
themeShade String?
Theme color shade (e.g. '80' for 20% darker).
final
themeTint String?
Theme color tint (e.g. '66' for 40% lighter).
final
xmlStyle String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited