NumberingParser class

Parses numbering definitions from numbering.xml.

Constructors

NumberingParser(ReaderContext context)

Properties

context ReaderContext
final
hashCode int
The hash code for this object.
no setterinherited
numberings Map<int, DocxNumberingDef>
Gets parsed numbering definitions.
no setter
pictureBullets Map<int, String>
Gets parsed picture bullets.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getLevel(int numId, int ilvl) DocxNumberingLevel?
Gets the level definition for a numbering.
getNumbering(int numId) DocxNumberingDef?
Gets the numbering definition for a numId.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(String xmlContent) → void
Parse numbering.xml content.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited