DocxBlock class abstract
Base class for block-level elements (paragraphs, tables, etc.).
Block elements start on a new line and take up the full width of their container.
- Inheritance
- Implementers
Properties
Methods
-
accept(
DocxVisitor visitor) → void -
Accepts a visitor for traversing the AST.
inherited
-
buildXml(
XmlBuilder builder) → void -
Converts this node to its XML representation.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited