DocxFont class
Represents the w:rFonts element properties.
Ensures fidelity by preserving distinct font families for different script types.
Constructors
Properties
- ascii → String?
-
The font used for ASCII characters (0-127).
final
- asciiTheme → String?
-
Theme font for ASCII characters.
final
- cs → String?
-
The font used for Complex Script characters (Arabic, etc.).
final
- csTheme → String?
-
Theme font for Complex Script characters.
final
- eastAsia → String?
-
The font used for East Asian characters.
final
- eastAsiaTheme → String?
-
Theme font for East Asian characters.
final
- family → String?
-
Returns the primary font family (ascii) for simple usage.
no setter
- hAnsi → String?
-
The font used for High ANSI characters (128-255).
final
- hAnsiTheme → String?
-
Theme font for High ANSI characters.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hint → String?
-
The hint attribute (e.g. 'eastAsia').
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
copyWith(
{String? ascii, String? hAnsi, String? cs, String? eastAsia, String? hint, String? asciiTheme, String? hAnsiTheme, String? csTheme, String? eastAsiaTheme}) → DocxFont -
merge(
DocxFont? other) → DocxFont - Merges this font with another, letting the other override non-null values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
withFamily(
String family) → DocxFont - Changes the font family for all non-null slots, or sets all if none set.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited