DocxIdTracker class
Tracks and validates document IDs to prevent duplicates.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
usedDocIds
→ Set<
String> -
Gets all used document IDs.
no setter
-
usedIds
→ Set<
int> -
Gets all used IDs.
no setter
-
usedRIds
→ Set<
String> -
Gets all used relationship IDs.
no setter
Methods
-
clear(
) → void - Clears all tracked IDs.
-
generateUniqueDocId(
) → String - Generates a unique document ID.
-
isDocIdUsed(
String docId) → bool - Checks if a document ID is already used.
-
isIdUsed(
int id) → bool - Checks if an ID is already used.
-
isRIdUsed(
String rId) → bool - Checks if a relationship ID is already used.
-
nextAvailableId(
{int from = 1}) → int - Gets the next available ID starting from a value.
-
nextAvailableRId(
{int from = 1}) → String - Gets the next available relationship ID.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerUsedDocId(
String docId) → void - Registers a document ID as used.
-
registerUsedId(
int id) → void - Registers an ID as used.
-
registerUsedRId(
String rId) → void - Registers a relationship ID as used.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited