DocxVisitor class abstract
Visitor interface for traversing the document AST.
Implement this to create custom exporters or processors.
class HtmlVisitor implements DocxVisitor {
final StringBuffer _buffer = StringBuffer();
@override
void visitText(DocxText text) {
_buffer.write('<span>${text.content}</span>');
}
// ... other visit methods
}
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
visitHeader(
covariant DocxNode header) → void -
visitImage(
covariant DocxNode image) → void -
visitParagraph(
covariant DocxBlock paragraph) → void -
visitRawInline(
covariant DocxNode rawInline) → void -
visitRawXml(
covariant DocxNode rawXml) → void -
visitSection(
covariant DocxNode section) → void -
visitShape(
covariant DocxInline shape) → void -
visitShapeBlock(
covariant DocxBlock shapeBlock) → void -
visitTable(
covariant DocxBlock table) → void -
visitTableCell(
covariant DocxNode cell) → void -
visitTableOfContents(
covariant DocxBlock toc) → void -
visitTableRow(
covariant DocxNode row) → void -
visitText(
covariant DocxInline text) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited